#
# spec file for package libstatgrab
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define soname  10
Name:           libstatgrab
Version:        0.92.1
Release:        1.13
Summary:        Interface to System Statistics
License:        LGPL-2.1-or-later
Group:          Development/Libraries/C and C++
URL:            https://libstatgrab.org/
Source:         https://github.com/libstatgrab/libstatgrab/releases/download/LIBSTATGRAB_0_92_1/libstatgrab-%{version}.tar.gz
Source1:        statgrab.desktop
Source2:        saidar.desktop
Source3:        baselibs.conf
Source4:        %{name}-rpmlintrc
BuildRequires:  autoconf >= 2.69
BuildRequires:  automake
BuildRequires:  gcc
BuildRequires:  glibc-devel
BuildRequires:  libtool
BuildRequires:  make
BuildRequires:  ncurses-devel
BuildRequires:  pkgconfig
%if 0%{?suse_version}
BuildRequires:  fdupes
BuildRequires:  update-desktop-files
%endif

%description
The libstatgrab library provides an easy-to-use interface for accessing system
statistics and information.
Available statistics include CPU, Load, Memory, Swap, Disk I/O, and Network
I/O. It was developed to work on Linux, FreeBSD, and Solaris.

The package also includes two tools: saidar provides a curses-based interface
for viewing live system statistics, and statgrab is a sysctl-like interface to
the statistics.

%package -n %{name}%{soname}
Summary:        Library for %{name}
License:        LGPL-2.1-or-later
Group:          Development/Libraries/C and C++

%description -n %{name}%{soname}
Library for package libstatgrab.

%package devel
Summary:        Development Environment for %{name}
License:        LGPL-2.1-or-later
Group:          Development/Libraries/C and C++
Requires:       %{name}%{soname} = %{version}

%description devel
Development environment for libstatgrab (headers, library links, static library).

%package -n statgrab
Summary:        Portable System Statistics Tools
License:        GPL-2.0-or-later
Group:          System/Monitoring
Requires:       %{name}%{soname} = %{version}

%description -n statgrab
This package includes a couple of useful tools that use the %{name} library.
- statgrab: gives a sysctl-style interface to the statistics gathered by libstatgrab
This extends the use of libstatgrab to people writing scripts or anything else
that can't easily make C function calls.
Included with this package is a script to generate an MRTG configuration file
to use statgrab.

%package -n saidar
Summary:        Portable System Statistics Tools
License:        GPL-2.0-or-later
Group:          System/Monitoring
Requires:       %{name}%{soname} = %{version}

%description -n saidar
This package includes a couple of useful tools that use the %{name} library.
- saidar: provides a curses-based interface to viewing the current state of the system
This extends the use of libstatgrab to people writing scripts or anything else
that can't easily make C function calls.

%prep
%setup -q

%build
autoreconf -fi

%configure \
	--docdir=%{_docdir}/%{name} \
	--enable-statgrab \
	--enable-saidar \
	--disable-examples \
	--disable-setuid-binaries \
	--disable-setgid-binaries \
	--disable-static \
	--with-curses-prefix=%{_includedir}/

%make_build

%install
%make_install

# Remove not needed static libraries
rm -f %{buildroot}%{_libdir}/%{name}.la

# install Desktop file
mkdir -p  %{buildroot}%{_datadir}/applications
install -Dm 0644 %{SOURCE1} %{buildroot}%{_datadir}/applications/
install -Dm 0644 %{SOURCE2} %{buildroot}%{_datadir}/applications/

%if 0%{?suse_version}
    %suse_update_desktop_file -r saidar System Monitor
    %suse_update_desktop_file -r statgrab System Monitor
    %fdupes -s %{buildroot}%{_prefix}
%endif

# install Examples
rm -fr examples/Makefile*
cp -a examples %{buildroot}%{_docdir}/%{name}/examples/

%post -n %{name}%{soname} -p /sbin/ldconfig
%postun -n %{name}%{soname} -p /sbin/ldconfig

%files -n %{name}%{soname}
%{_libdir}/%{name}.so.*

%files devel
%doc %{_docdir}/%{name}
%{_includedir}/statgrab.h
%{_libdir}/pkgconfig/%{name}.pc
%{_libdir}/%{name}.so
%{_mandir}/man3/sg_*.3%{?ext_man}
%{_mandir}/man3/statgrab.3%{?ext_man}
%{_mandir}/man3/%{name}.3%{?ext_man}

%files -n statgrab
%license COPYING
%{_bindir}/statgrab
%{_bindir}/statgrab-make-mrtg-config
%{_bindir}/statgrab-make-mrtg-index
%{_mandir}/man1/statgrab.1%{?ext_man}
%{_mandir}/man1/statgrab-make-mrtg-config.1%{?ext_man}
%{_mandir}/man1/statgrab-make-mrtg-index.1%{?ext_man}
%{_datadir}/applications/statgrab.desktop

%files -n saidar
%license COPYING
%{_bindir}/saidar
%{_mandir}/man1/saidar.1%{?ext_man}
%{_datadir}/applications/saidar.desktop

%changelog
* Fri Jan 28 2022 Dirk Müller <dmueller@suse.com>
- update to 0.92.1
  * Fix build with autoconf 2.70+.
  * Fix CPU stats on older Linux kernels.
  * Make sure to count processes in an unknown state.
  * Check if -ltinfo is needed when linking ncurses.
  * Fixes to build when cross-compiling.
  * Fix build with -DNDEBUG.
  * Handle vmmeter changes in FreeBSD 12.
* Mon Aug 24 2020 Dirk Mueller <dmueller@suse.com>
- update to 0.92:
  * Fix various file descriptor leaks.
  * On Linux, read process thread name from comm where available (fixes FreeScale ARM BSP).
  * Add more process stat information on MacOS/Darwin.
  * Fix build on Alpine Linux and NetBSD 8.
  * Fix build on FreeBSD 12 without COMPAT_FREEBSD11.
  * Improve collection of data for non-standard Solaris interfaces.
  * Improve detection of interface link status on Solaris.
  * Various configure and build fixes.
  * Ensure modern log4cplus is used correctly.
* Wed Jan  3 2018 dimstar@opensuse.org
- baselibs.conf: fix dependency of libstatgrab-devel-32bit.
* Fri Mar 24 2017 aj@ajaissle.de
- BuildRequires autoconf >= 2.69
* Fri Nov 27 2015 nemysis@openSUSE.org
- Update to 0.91, please see
  /usr/share/doc/packages/libstatgrab/NEWS
- Change soname to 10 and change baselibs.conf
- Remove obsolete patches libstatgrab-os-linux.diff,
  libstatgrab-link-ncurses.diff, libstatgrab-fix-include-ncurses.patch,
  changed by Upstream
- Add libstatgrab-rpmlintrc, for not fixable issues
- Modernize spec
- Add BuildRequires for fdupes and use %%fdupes macro to reduce size
  of the package
- Reorder %%configure default options
- Use default %%make_install
* Sun Feb 19 2012 pascal.bleser@opensuse.org
- update to 0.17:
  * provide iowait cpu information on Linux version 2.5.41 or later
  * use utmpx when available
* Thu Jan 12 2012 coolo@suse.com
- change license to be in spdx.org format
* Fri Sep 16 2011 jengelh@medozas.de
- Implement baselibs for package
- Remove redundant tags/sections; use %%_smp_mflags
* Fri Apr 15 2011 schubi@novell.com
- Fixed requirements of devel package
* Sun Feb 13 2011 ro@suse.de
- fix requires for subpackages
* Tue Feb  8 2011 schubi@novell.com
- Cleanup spec file
* Tue Feb  8 2011 schubi@novell.com
- Rename the main package to libstatgrab
- Create a subpackage libstatgrab6
- Create a subpackage libstatgrab-devel
* Fri Feb  4 2011 schubi@novell.com
- initial version 0.16
